@@ -147,8 +147,10 @@ class CustomFormatter(logging.Formatter):
 class ExcludeProfilingStreamHandler(logging.StreamHandler):
 
     def emit(self, record: logging.LogRecord) -> None:
-        if record.levelno != 7:
+        if record.levelname.casefold() != 'PROFILE'.casefold():
             return super().emit(record)
+        else:
+            return
 
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
